@@ -124,6 +124,7 @@ class BaseExperiment:
         path : Optional[str] = None
     )->None:
         r"""
+
         Args:
 
             project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
@@ -166,6 +167,7 @@ class BaseExperiment:
         Returns:
 
             None
+
         """
         self.project_name = project_name
         self.X = X
@@ -215,12 +217,16 @@ class BaseExperiment:
         
 
     def update_log_path(self)->None:
-        r"""Updates log path"""
+        r"""Updates log path
+
+        """
         self.exp_path = f'{self.project_path}/{self.fit_or_cv}/random_state-{self.random_state}'
         self.log_path = f'{self.exp_path}/logs'
 
     def update_exp_metadata(self)->None:
-        r"""Upates exp_metadata."""
+        r"""Upates exp_metadata.
+        
+        """
         self.exp_metadata.update({'# of checkpoints saved' : int(self.n_ckpts)})
         self.exp_metadata.update({'size of the experiment in MB' : float(os.path.getsize(self.exp_path)/10**6)})
         self.exp_metadata.update({'size of stack in MB': float(sys.getsizeof(self.stack)/10**6)})
@@ -296,6 +302,7 @@ class BaseExperiment:
                         return torch.optim.Adam(self.parameters(), lr=0.02)
 
             >>> exp.set_model(LitModel)
+
         """
         if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type): # astrape models
             self.model = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
@@ -470,6 +477,7 @@ class BaseExperiment:
         Returns:
             
             `pl.Trainer`: trainer
+
         """
         if self.model is None:
             raise AssertionError("Model must be defined first in order to set metadata. Use .model(model_type, **hparams) to declare a model.")
@@ -519,6 +527,7 @@ class BaseExperiment:
         Returns:
 
             `pl.LightningModule` or `BaseEstimator`: self.model
+
         """
 
         if self.model is None:
@@ -634,7 +643,7 @@ class BaseExperiment:
 
         Note:
 
-            If self.model is a variant of sklearn, we save model states as `.sav` file.
+            If self.model is a variant of sklearn, we save model states as ``.sav`` file.
             If self.model is a LightningModule, we use ``save_checkpoint`` method from pl.Trainer class.
 
             ``save_checkpoint`` method from pl.Trainer class saves the followings to a `.ckpt` file.
@@ -658,6 +667,7 @@ class BaseExperiment:
                 exp.save_ckpt()
                 # Loading the model: 
                 saved_ckpt = MLP.load_from_checkpoint(checkpoint_path=f'{ckpt_path}')
+
         """
         if model is None:
             model = self.model
@@ -718,6 +728,7 @@ class BaseExperiment:
         Raises:
 
             AssertionError: If there were no log informations for the specified model.
+
         """
         has_val_loss = False
         has_val_acc = False
@@ -786,6 +797,7 @@ class BaseExperiment:
         Note:
         
             ``stack`` will be flushed after saving.
+
         """
         for subject in self.stack:
             self.save_ckpt(**subject)
@@ -841,6 +853,7 @@ class BaseExperiment:
         Returns: 
             
             :obj:LightningModule or None: The best checkpoint(or the path if fetch_only_dir is True) as per the validation metric you defined in the argument. Returns None if there are no saved checkpoints
+
         """
         try:
             jsonlogdir = f"{self.log_path}/jsonlogs"
@@ -986,6 +999,7 @@ class BaseExperiment:
         Note:
 
             Metadata of a model is a string that specifies: {model type}-{hyperparameters}
+
         """
         hparams_str = self._params_to_str(hparams)
         hparams_str = "default_hyperparameters" if hparams_str == "" else hparams_str
@@ -1022,6 +1036,7 @@ class BaseExperiment:
    
     def get_hparams(self, model):
         r"""Gets hyperparameter or model specs.
+
         """
         if isinstance(model, BaseEstimator):
             return self.set_model_metadata(model, model.__dict__)
@@ -1053,6 +1068,7 @@ class BaseExperiment:
         Returns:
 
             None
+
         """
         log = {'model_type' : model.__class__.__name__}
         error_count = 0
@@ -1126,18 +1142,23 @@ class BaseExperiment:
 
     def toggle_stack(self):
         r"""Toggles stack_models.
+
         """
         self.stackflag = not self.stackflag
         self.stack_models = not self.stack_models
 
     @staticmethod
     def _create_folder(directory : str)->str:
-        r"""Creates folder. If folder already exists, does nothing."""
+        r"""Creates folder. If folder already exists, does nothing.
+        
+        """
         os.makedirs(directory, exist_ok=True)
         return directory
 
     @staticmethod
     def _params_to_str(dictionary : dict)->str:
-        r"""Returns a string version of passed arguments. Applied when defining hparams and using **hparams to pass arguments."""
+        r"""Returns a string version of passed arguments. Applied when defining hparams and using **hparams to pass arguments.
+        
+        """
         out = str(dictionary).replace("{", "").replace("}","").replace(" ","-").replace(":","").replace("-","").replace("\n", "-").replace('"', "").replace(".","d").replace("'","").replace(",","_")
         return out
