@@ -151,6 +151,8 @@ class _MLP(nn.Module):
 
 
 class MLP(BaseNet):
+    r"""Multi-layer perceptron with identical # of hidden units.
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -158,7 +160,40 @@ class MLP(BaseNet):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         **hparams : Any
     ) -> None:
-        
+        r"""Multi-layer perceptron with identical # of hidden units.
+
+            The number of layers are specified with argument ``n_layers``.
+
+            Args:
+
+                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+                n_classes (int, optional): Number of classes (labels) in the classification task.
+                
+                n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
+                    Default: ``2``
+
+                n_hidden_units (int): Number of hidden units for all hidden layers. 
+                    Default : ``10`` 
+
+                batch_size (int): Batch size. 
+                    Default : ``64``
+
+                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                    Default : ``"adam"`` 
+
+                dropout_p (float): Dropout probability 
+                    Default : ``0``
+
+                bn (bool): Whether to use batch normalization or not. 
+                    Default : ``True``
+
+                weight_decay (float): Coefficient for L2-regularization. 
+                    Default : ``0`` 
+
+                lr (float): Learning rate. 
+                    Default: ``1e-4``
+        """
         
         entire_keys = [
             'dims', 
@@ -209,54 +244,21 @@ class MLP(BaseNet):
 
     def forward(self, X):
         return self.model.forward(X)
-
-    def help(self) -> None :
-        whoami = "Multi-Layer Perceptron\n\n"
-        helptext = "Parameters ------------------------------------------------------------------------------------------------------- \n"
-        helptext += "dims:\t Dimension of the data. Normally X.shape[1].\n"
-        helptext += "n_classes:\t Number of classes in the classification task. If it is binary classification, 'n_classes' = 2\n"
-        helptext += "In defining hyperparameters and optimizer_type, we recommend you to define a dictionary.\n"
-        helptext += "Define a dictionary containing :\n\t-'optimizer_type': str (default='adam')\n\t-'n_layers' : int (default=2)\n\t-'n_hidden_units' : int (default=10)\n\t-'dropout_p' : 0 <= float < 1 (default=0)\n\t-'weight_decay' : 0<= float < 1(default=0)\n\t-'lr' : float(default=1e-4)."
-        
-        text= whoami + helptext
-        print(text)
 ########################################################## _MLP & MLP (Ends) ##########################################################
 
 
 ########################################################## _ContractingMLP & ContractingMLP (Begins) ##########################################################
-"""
-_ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
-of contraction_ratio.
-Therefore, the hyperparameter that is additionally defined in ContractingMLP is contraction_ratio.
 
-_ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
-_ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
-
-Arguments:
-    - dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (8,8,1)
-
-    - n_classes (Optional[int]) : Number of classes (labels) in the classification task.
-                                    Do not specify this argument (set is as None) when you 
-                                    are performing regression tasks.
-    
-    - contraction_ratio (0 < float < 1) : The contraction ratio for n_hidden_units. Default : 0.5
-
-    - batch_size (int) : Batch size. Default : 64 (see utils_lightning.py)
-
-    - optimizer_type (str) : Type of the optimizer. ("adam" or "sgd") Default : "adam" (see utils_lightning.py) 
-                            #TODO : implement other optimizers.(in model_base.py)
-
-    - dropout_p (0<= float < 1) : Dropout probability Default : 0 (see utils_lightning.py)
-
-    - bn (bool) : Whether to use batch normalization or not. Default : True (see utils_lightning.py)
-
-    - weight_decay (0<= float) : coefficient for L2-regularization. Default : 0 (see utils_lightning.py)
-
-    - lr ( 0 < float) : Learning rate. Default: 1e-4 (see utils_lightning.py)
-
-
-"""
 class _ContractingMLP(nn.Module):
+    r"""ContractingMLP with given contraction ratio.
+
+    _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
+    of contraction_ratio.
+    Therefore, the hyperparameter that is additionally defined in ContractingMLP is contraction_ratio.
+
+    _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
+    _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -273,6 +275,35 @@ class _ContractingMLP(nn.Module):
         negative_slope : Optional[float] = None,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ) -> None:
+        r"""Initialize ContractingMLP
+        
+            Args:
+            
+                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+                n_classes (int, optional): Number of classes (labels) in the classification task.
+                
+                contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+                    Default: ``0.5``
+
+                batch_size (int): Batch size. 
+                    Default : ``64``
+
+                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                    Default : ``"adam"`` 
+
+                dropout_p (float): Dropout probability 
+                    Default : ``0``
+
+                bn (bool): Whether to use batch normalization or not. 
+                    Default : ``True``
+
+                weight_decay (float): Coefficient for L2-regularization. 
+                    Default : ``0`` 
+
+                lr (float): Learning rate. 
+                    Default: ``1e-4``
+    """
         super(_ContractingMLP, self).__init__()
 
         if isinstance(dims, tuple):
@@ -368,6 +399,15 @@ class _ContractingMLP(nn.Module):
         return self.layers(X)
 
 class ContractingMLP(BaseNet):
+    r"""ContractingMLP with given contraction ratio.
+    
+    _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
+    of contraction_ratio.
+    Therefore, the hyperparameter that is additionally defined in ContractingMLP is contraction_ratio.
+
+    _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
+    _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -375,6 +415,35 @@ class ContractingMLP(BaseNet):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         **hparams : Any
     ) -> None:
+        r"""Initialize ContractingMLP
+        
+            Args:
+            
+                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+                n_classes (int, optional): Number of classes (labels) in the classification task.
+                
+                contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+                    Default: ``0.5``
+
+                batch_size (int): Batch size. 
+                    Default : ``64``
+
+                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                    Default : ``"adam"`` 
+
+                dropout_p (float): Dropout probability 
+                    Default : ``0``
+
+                bn (bool): Whether to use batch normalization or not. 
+                    Default : ``True``
+
+                weight_decay (float): Coefficient for L2-regularization. 
+                    Default : ``0`` 
+
+                lr (float): Learning rate. 
+                    Default: ``1e-4``
+        """
         
         entire_keys = [
             'dims', 
